Skip to main content

visa-cli

A CLI app to lookup Passport Index based on https://github.com/ilyankou/passport-index-dataset

PyPI GitHub

Installation

pip install visa-cli

Usage

usage: visa-cli [-h] [-d DESTINATION_COUNTRY] [-f] [-r] [-o] [-e] [-n] [-c]
                [-i] [-l RESIDENT_COUNTRIES]
                resident_country

positional arguments:
  resident_country      Current Resident Country

optional arguments:
  -h, --help            show this help message and exit
  -d DESTINATION_COUNTRY, --destination-country DESTINATION_COUNTRY
                        Destination Country
  -f, --visa-free       Countries not requiring Visa
  -r, --visa-required   Countries requiring Visa
  -o, --visa-on-arrival
                        Countries offering Visa on arrival
  -e, --eta             Countries offering Electronic Travel Authority
  -n, --visa-free-days  Countries offering Visa free days
  -c, --covid-ban       Countries not offering Visa due to Covid-19
  -i, --interactive     Interactive Prompt
  -l RESIDENT_COUNTRIES, --resident-countries RESIDENT_COUNTRIES
                        A list of Resident Countries in addition to the
                        Current Resident Country. Format argument in a comma-
                        delimited string "Israel, Russia, China"

  • Lookup on an interactive prompt
$ visa-cli -i Vatican

__     __ ___  ____      _             ____  _      ___
\ \   / /|_ _|/ ___|    / \           / ___|| |    |_ _|
 \ \ / /  | | \___ \   / _ \   _____ | |    | |     | |
  \ V /   | |  ___) | / ___ \ |_____|| |___ | |___  | |
   \_/   |___||____/ /_/   \_\        \____||_____||___|


Downloading Visa data...

Press Any Key to Exit!


Destination Country:Italy
90


Destination Country:United States
visa required


Destination Country:Romania
90


Destination Country:_
                     Albania
                     Algeria
                     Andorra


  • Lookup for a particular resident and destination Country.
$ visa-cli  Vatican -d Russia

__     __ ___  ____      _             ____  _      ___
\ \   / /|_ _|/ ___|    / \           / ___|| |    |_ _|
 \ \ / /  | | \___ \   / _ \   _____ | |    | |     | |
  \ V /   | |  ___) | / ___ \ |_____|| |___ | |___  | |
   \_/   |___||____/ /_/   \_\        \____||_____||___|


Downloading Visa data...

╒═════╤═══════════════════════╤═══════════╕
│     │ Destination Country   │ Status    │
╞═════╪═══════════════════════╪═══════════╡
│ 144 │ Russia                │ covid ban │
╘═════╧═══════════════════════╧═══════════╛

  • Lookup for a group of resident Countries.
$ visa-cli  Israel  -l "Germany, Austria, India" -d Canada

__     __ ___  ____      _             ____  _      ___
\ \   / /|_ _|/ ___|    / \           / ___|| |    |_ _|
 \ \ / /  | | \___ \   / _ \   _____ | |    | |     | |
  \ V /   | |  ___) | / ___ \ |_____|| |___ | |___  | |
   \_/   |___||____/ /_/   \_\        \____||_____||___|


Downloading Visa data...

Visa Status for various Resident Countries


╒════╤════════════════════╤═══════════════════════╤═══════════╕
│    │ Resident Country   │ Destination Country   │ Status    │
╞════╪════════════════════╪═══════════════════════╪═══════════╡
│  0 │ Israel             │ Canada                │ covid ban │
├────┼────────────────────┼───────────────────────┼───────────┤
│  1 │ Germany            │ Canada                │ covid ban │
├────┼────────────────────┼───────────────────────┼───────────┤
│  2 │ Austria            │ Canada                │ covid ban │
├────┼────────────────────┼───────────────────────┼───────────┤
│  3 │ India              │ Canada                │ covid ban │
╘════╧════════════════════╧═══════════════════════╧═══════════╛

Metadata

Release files for visa-cli 0.2.1

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for visa-cli 0.2.1
File Size Uploaded
visa-cli-0.2.1.tar.gz 9.7 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for visa-cli 0.2.1
File Interpreter ABI Platform
visa_cli-0.2.1-py3-none-any.whl Python 3 none any Details

Total release size: 19.5 kB

Release files / visa-cli-0.2.1.tar.gz

Download URL visa-cli-0.2.1.tar.gz
Size 9.7 kB
Tags Source
SHA-256 checksum
How to use checksums
068d7e53722931f1f364dd8b0958dd73af8fce4cb9fe15ad4d7e4e7e63fdf5bc
BLAKE2b-256 checksum
How to use checksums
bf945c56392fff78370a4ff730291b2a1305f9bd688b1c420702c8664b8d46d9
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.8.0 pkginfo/1.8.2 readme-renderer/32.0 requests/2.27.1 requests-toolbelt/0.9.1 urllib3/1.26.8 tqdm/4.63.0 importlib-metadata/4.11.2 keyring/23.5.0 rfc3986/2.0.0 colorama/0.4.4 CPython/3.8.12

Release files / visa_cli-0.2.1-py3-none-any.whl

Download URL visa_cli-0.2.1-py3-none-any.whl
Size 9.8 kB
Tags Python 3
SHA-256 checksum
How to use checksums
fb23432a79e01b996ba1cec47a189f3793b878b8b2a17bbb09cb1f7f0c32246d
BLAKE2b-256 checksum
How to use checksums
7ca5f6f9862cd450f337becb85615f4145240bde0348be18ed93a4ff2188900b
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.8.0 pkginfo/1.8.2 readme-renderer/32.0 requests/2.27.1 requests-toolbelt/0.9.1 urllib3/1.26.8 tqdm/4.63.0 importlib-metadata/4.11.2 keyring/23.5.0 rfc3986/2.0.0 colorama/0.4.4 CPython/3.8.12

Release history Release notifications | RSS feed

This release

0.2.1 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page